import { type Parser as CSSParser } from "@siteimprove/alfa-css";
import type { Device } from "@siteimprove/alfa-device";
import type * as json from "@siteimprove/alfa-json";
import type { Feature } from "../feature.js";
import type { Condition } from "./condition.js";
export declare class Or<F extends Feature<F>> implements Feature<F, Or.JSON<F>> {
    static of<F extends Feature<F>>(left: Condition<F>, right: Condition<F>): Or<F>;
    private readonly _left;
    private readonly _right;
    private constructor();
    get left(): Condition<F>;
    get right(): Condition<F>;
    matches(device: Device): boolean;
    equals(value: unknown): value is this;
    private iterator;
    [Symbol.iterator](): Iterator<F>;
    toJSON(): Or.JSON<F>;
    toString(): string;
}
export declare namespace Or {
    interface JSON<F extends Feature<F>> {
        [key: string]: json.JSON;
        type: "or";
        left: Condition.JSON<F>;
        right: Condition.JSON<F>;
    }
    function isOr<T extends Feature<T>>(value: unknown): value is Or<T>;
    /**
     * {@link https://drafts.csswg.org/mediaqueries-5/#typedef-media-or}
     *
     * @internal
     */
    function parse<F extends Feature<F>>(parseInParens: (featureParser: CSSParser<F>) => CSSParser<Condition<F>>, featureParser: CSSParser<F>): CSSParser<Condition<F>>;
}
//# sourceMappingURL=or.d.ts.map