import { Token } from "@siteimprove/alfa-css";
import type { Device } from "@siteimprove/alfa-device";
import { Option } from "@siteimprove/alfa-option";
import { Parser } from "@siteimprove/alfa-parser";
import type * as json from "@siteimprove/alfa-json";
import { Condition } from "../condition/index.js";
import type { Feature } from "../feature.js";
import { Media } from "./feature/index.js";
import { Modifier } from "./modifier.js";
import { Type } from "./type.js";
/**
 * {@link https://drafts.csswg.org/mediaqueries-5/#media-query}
 *
 * @remarks
 * Media query can contain both a modifier, type and media feature.
 *
 * @public
 */
export declare class Query implements Feature<Condition<Media>, Query.JSON> {
    static of(modifier: Option<Modifier>, type: Option<Type>, condition: Option<Condition<Media>>): Query;
    private readonly _modifier;
    private readonly _type;
    private readonly _condition;
    private constructor();
    get modifier(): Option<Modifier>;
    get type(): Option<Type>;
    get condition(): Option<Condition<Media>>;
    matches(device: Device): boolean;
    private iterator;
    [Symbol.iterator](): Iterator<Condition<Media>>;
    equals(value: unknown): value is this;
    toJSON(): Query.JSON;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Query {
    interface JSON {
        [key: string]: json.JSON;
        modifier: string | null;
        type: Type.JSON | null;
        condition: Condition.JSON<Media> | null;
    }
    function isQuery(value: unknown): value is Query;
    /**
     * @internal
     */
    const notAll: Query;
    /**
     * {@link https://drafts.csswg.org/mediaqueries-5/#typedef-media-query}
     */
    const parse: Parser<import("@siteimprove/alfa-slice").Slice<Token>, Query, string, []>;
}
//# sourceMappingURL=query.d.ts.map